@@ -86,7 +86,7 @@
 #define KCONFIGGUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONFIGGUI_NO_DEPRECATED
-#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54400
+#  define KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55000
 #endif
 #ifdef KCONFIGGUI_NO_DEPRECATED_WARNINGS
 #  define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE KCONFIGGUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x54400
+#    define KCONFIGGUI_DEPRECATED_WARNINGS_SINCE 0x55000
 #  endif
 #endif
 
@@ -121,7 +121,14 @@
 #else
 #  define KCONFIGGUI_DEPRECATED_VERSION_5_39(text)
 #endif
+
+#if KCONFIGGUI_DEPRECATED_WARNINGS_SINCE >= 0x54700
+#  define KCONFIGGUI_DEPRECATED_VERSION_5_71(text) KCONFIGGUI_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCONFIGGUI_DEPRECATED_VERSION_5_71(text)
+#endif
 #define KCONFIGGUI_DEPRECATED_VERSION_5(minor, text)      KCONFIGGUI_DEPRECATED_VERSION_5_##minor(text)
 #define KCONFIGGUI_DEPRECATED_VERSION(major, minor, text) KCONFIGGUI_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KCONFIGGUI_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCONFIGGUI_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KCONFIGGUI_EXPORT_H */
